@@ -56,7 +56,7 @@ typedef enum {
 	GDA_SERVER_OPERATION_CREATE_VIEW,
 	GDA_SERVER_OPERATION_DROP_VIEW,
 
-	GDA_SERVER_OPERATION_NB
+	GDA_SERVER_OPERATION_LAST
 } GdaServerOperationType;
 
 typedef enum {
