@@ -11,10 +11,10 @@
 #define fail_unless(x,y) if (!(x)) g_warning (y)
 
 int prov_test_common_setup ();
-int prov_test_common_create_tables_sql ();
 int prov_test_common_load_data ();
 int prov_test_common_check_meta ();
 int prov_test_common_check_cursor_models ();
+int prov_test_common_check_data_select ();
 int prov_test_common_clean ();
 
 #endif
